@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2013 Emweb bvba, Leuven, Belgium.
+ * Copyright (C) 2013 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -159,6 +159,12 @@ public:
    */
   const WAxis& axis(Axis axis) const;
 
+  /*! \brief Sets an axis
+   *
+   * \sa axis(Axis axis)
+   */
+  void setAxis(std::unique_ptr<WAxis> waxis, Axis axis);
+
   /*! \brief Enable/disable gridlines.
    *
    * Enables or disables gridlines in the given plane, along the given axis. 
@@ -207,7 +213,7 @@ public:
   void setIntersectionPlanes
     (const std::vector<IntersectionPlane> &intersectionPlanes);
 
-  /*! \brief Method::Get the invisible planes with which intersections are drawn.
+  /*! \brief Get the invisible planes with which intersections are drawn.
    *
    * \sa setIntersectionPlanes()
    */
@@ -316,15 +322,6 @@ public:
    */
   const WFont& titleFont() const { return titleFont_; }
 
-  //void resetView();
-
-  // /*! \brief 
-  //  */
-  // WLegend & legend() { return legend_; }
-  // /*! \brief 
-  //  */
-  // const WLegend & legend() const { return legend_; }
-
   /*! \brief Enables the legend.
    *
    * The location of the legend can be configured using
@@ -440,6 +437,7 @@ public:
    * method of WMatrix4x4. A common use-case when manipulating the matrix is to
    * translate the center to the origin and then rotate.
    * 
+   * \if cpp
    * For example:
    * \code{.cpp}
    *   ...
@@ -454,10 +452,11 @@ public:
    * 
    *   camera.translate(-0.5, -0.5, -0.5);
    * \endcode
+   * \endif
    */
   void setCameraMatrix(const WMatrix4x4& matrix);
 
-  /*! \brief Method::Get the current camera-matrix.
+  /*! \brief Get the current camera-matrix.
    *
    * The matrix represents the current view on the scene. It corresponds to
    * a coordinate system where the chart's axes run from 0 to 1 in all three
@@ -467,7 +466,7 @@ public:
    */
   WMatrix4x4 cameraMatrix() const;
 
-  /*! \brief Method::Get the current camera matrix as a JavaScriptMatrix4x4.
+  /*! \brief Get the current camera matrix as a JavaScriptMatrix4x4.
    *
    * This JavaScriptMatrix4x4 can be used to implement a custom mouse
    * handler using setClientSideMouseHandler().
@@ -546,8 +545,8 @@ private:
 
   WMatrix4x4 worldTransform_;
   bool isViewSet_;
-  std::vector<std::unique_ptr<WAbstractDataSeries3D>> dataSeriesVector_;
-  WAxis XAxis_, YAxis_, ZAxis_;
+  std::vector<std::unique_ptr<WAbstractDataSeries3D> > dataSeriesVector_;
+  std::unique_ptr<WAxis> xAxis_, yAxis_, zAxis_;
   ChartType chartType_;
 
   bool XYGridEnabled_[2], XZGridEnabled_[2], YZGridEnabled_[2];
